import{x as r,c as l,e as p,X as u,i as v,w as d,Y as f,D as m}from"./index-CLKg64ON.js";import{_ as b}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{s as h}from"./VListItem-B_TSjQ1y.js";const w={props:{variant:{type:String,default:"default",validator:e=>["plain","default","responsive","icon","list"].includes(e)}},setup(e,a){const t={},s=r(()=>({...t,class:"v-btn--variant-responsive",ripple:!0,icon:!0,style:"height: min(calc(100vw - 40px), calc(100vh - 340px)); width: min(calc(100vw - 40px), calc(100vh - 340px));"})),o=r(()=>({...t,ripple:!1})),c=r(()=>({...t,density:"comfortable"}));return{btnProps:r(()=>{switch(e.variant){case"default":return t;case"plain":return t;case"responsive":return s.value;case"icon":return o.value;case"list":return c.value;default:return t}})}}};function x(e,a,t,s,o,c){return l(),p(h,m(s.btnProps,{variant:"plain"}),u({_:2},[v(e.$slots,(i,n)=>({name:n,fn:d(()=>[f(e.$slots,n)])}))]),1040)}const P=b(w,[["render",x]]);export{P as B};
