import{x as r,a8 as i,p as c,k as u,H as d,f as p,c as f,e as m,X as v,i as C,D as _,w as k,Y as P}from"./index-CLKg64ON.js";import{_ as y}from"./_plugin-vue_export-helper-DlAUqK2U.js";/* empty css              */import{m as V,a as g,b as h,u as w,c as $}from"./VListItem-B_TSjQ1y.js";const b={props:{variant:{type:String,default:"default",validator:e=>["default","panel"].includes(e)}},setup(e,n){const a=r(()=>({class:"container-default"})),t=r(()=>({class:i.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(e.variant){case"default":return a.value;case"panel":return t.value;default:return a.value}})}}},x=c({fluid:{type:Boolean,default:!1},...V(),...g(),...h()},"VContainer"),D=u()({name:"VContainer",props:x(),setup(e,n){let{slots:a}=n;const{rtlClasses:t}=d(),{dimensionStyles:s}=w(e);return $(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},t.value,e.class],style:[s.value,e.style]},a)),{}}});function S(e,n,a,t,s,l){return f(),m(D,_(t.btnProps,{variant:"default",fluid:""}),v({_:2},[C(e.$slots,(B,o)=>({name:o,fn:k(()=>[P(e.$slots,o,{},void 0,!0)])}))]),1040)}const L=y(b,[["render",S],["__scopeId","data-v-8ccf3252"]]);export{L as C};
