.list-item-main[data-v-4856ac34]{border-radius:4px!important;padding:7px 0 7px 7px!important}.list-item-main>div.v-list-item__append[data-v-4856ac34]{display:flex;justify-content:end;vertical-align:middle;align-items:center;padding:0}.list-item-main>div.v-list-item__prepend>.v-icon[data-v-4856ac34]{margin-inline-end:5px!important}.list-item-main>div.v-list-item__prepend>div[data-v-4856ac34]{display:flex!important;align-items:center!important}.list-item-main>div.v-list-item__append>.v-icon[data-v-4856ac34]{margin-inline-start:5px!important}.list-item-main>div.v-list-item__prepend>button[data-v-4856ac34]{margin-inline-end:5px!important}.list-item-main>div.v-list-item__append>button[data-v-4856ac34]{margin-inline-start:5px!important}.list-item-main>div.v-list-item__content>div[data-v-4856ac34]{padding-left:10px;padding-right:10px}
