.v-card[data-v-fe06d440]{transition:opacity .4s ease-in-out;padding:0;margin-bottom:10px}.v-card[data-v-fe06d440]:not(.on-hover){opacity:.75}.panel-item-details[data-v-fe06d440]{padding:5px!important;height:50px;bottom:5px}.hiresicon[data-v-fe06d440]{margin-left:10px;margin-right:10px}.hiresiconinverted[data-v-fe06d440]{margin-left:10px;margin-right:10px;filter:invert(100%)}.paneldetails[data-v-fe06d440],.paneldetails-dark[data-v-fe06d440]{background-color:#ffffffbf;position:absolute;width:100%;height:50px;bottom:0;border-radius:0}.paneldetails-dark[data-v-fe06d440]{background-color:#000000bf}
