import{B as v}from"./Button-F8l3l_P8.js";import{x as i,l as c,O as B,N as $,c as a,e as m,X as I,i as w,w as p,Y as l,a3 as u,j as M,D as k}from"./index-CLKg64ON.js";import{_ as C}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{V as h}from"./VListItem-B_TSjQ1y.js";const D={components:{MAButton:v},props:{showMenuBtn:{type:Boolean,default:!1}},setup(t,e){const s=i(()=>({}));return{listItemProps:i(()=>({...s.value,...e.attrs}))}}};function L(t,e,s,n,P,y){const d=c("MAButton"),f=B("hold");return $((a(),m(h,k(n.listItemProps,{class:"list-item-main",onInput:e[1]||(e[1]=o=>t.$emit("input",o)),onContextmenu:e[2]||(e[2]=u(o=>t.$emit("menu",o),["right","prevent"]))}),I({_:2},[w(t.$slots,(o,r)=>({name:r,fn:p(()=>[l(t.$slots,r,{},void 0,!0)])})),t.$slots.append||s.showMenuBtn?{name:"append",fn:p(()=>[l(t.$slots,"append",{},void 0,!0),s.showMenuBtn?(a(),m(d,{key:0,variant:"list",icon:"mdi-dots-vertical",onClick:e[0]||(e[0]=u(o=>t.$emit("menu",o),["stop"]))})):M("",!0)]),key:"0"}:void 0]),1040)),[[f,o=>t.$emit("menu",o)]])}const S=C(D,[["render",L],["__scopeId","data-v-4856ac34"]]);export{S as L};
