.header.v-toolbar[data-v-d4c433ce]{height:55px;font-family:JetBrains Mono Medium}.widget-row[data-v-d4c433ce]{margin-bottom:20px;margin-left:0;padding-left:0}.widget-row-panel-item[data-v-d4c433ce]{margin-bottom:10px}.v-slide-group__prev[data-v-d4c433ce]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-d4c433ce]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-d4c433ce]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-d4c433ce]{visibility:hidden}.v-progress-circular[data-v-efe9c45c]{display:block;margin-inline:auto}
