import{m as g,c as b,e as h,D as V,w as A,K as k,d as j,a as z,f as J,Y as K,E as U,F as W,g as Y,Z,b as q,G as Q,W as X,i as $,I as ee,k as ae,u as te,l as ne,S as de,O as ie,H as le,n as se,_ as ce,x as re,U as ue,J as ve}from"./VListItem-B_TSjQ1y.js";import{k as f,z as oe,f as n,p as S,ay as u,F as p,n as me,G as ye,x as P,N as ke,O as ge,D as be}from"./index-CLKg64ON.js";import{V as fe,a as Ie,b as Ce}from"./VCardText-BAUfdzDA.js";const Ve=f()({name:"VCardActions",props:g(),setup(e,i){let{slots:t}=i;return oe({VBtn:{slim:!0,variant:"text"}}),b(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),Ae=S({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:[String,Number],title:[String,Number],...g(),...h()},"VCardItem"),pe=f()({name:"VCardItem",props:Ae(),setup(e,i){let{slots:t}=i;return b(()=>{var s;const a=!!(e.prependAvatar||e.prependIcon),v=!!(a||t.prepend),l=!!(e.appendAvatar||e.appendIcon),o=!!(l||t.append),m=!!(e.title!=null||t.title),y=!!(e.subtitle!=null||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[v&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(k,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},t.prepend):n(p,null,[e.prependAvatar&&n(V,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&n(A,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null)])]),n("div",{class:"v-card-item__content"},[m&&n(fe,{key:"title"},{default:()=>{var d;return[((d=t.title)==null?void 0:d.call(t))??e.title]}}),y&&n(Ie,{key:"subtitle"},{default:()=>{var d;return[((d=t.subtitle)==null?void 0:d.call(t))??e.subtitle]}}),(s=t.default)==null?void 0:s.call(t)]),o&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(k,{key:"append-defaults",disabled:!l,defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},t.append):n(p,null,[e.appendIcon&&n(A,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&n(V,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])])])}),{}}}),Pe=S({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:[String,Number],text:[String,Number],title:[String,Number],...j(),...g(),...h(),...z(),...J(),...K(),...U(),...W(),...Y(),...Z(),...q(),...me(),...Q({variant:"elevated"})},"VCard"),De=f()({name:"VCard",directives:{Ripple:X},props:Pe(),setup(e,i){let{attrs:t,slots:a}=i;const{themeClasses:v}=ye(e),{borderClasses:l}=$(e),{colorClasses:o,colorStyles:m,variantClasses:y}=ee(e),{densityClasses:s}=ae(e),{dimensionStyles:d}=te(e),{elevationClasses:x}=ne(e),{loaderClasses:D}=de(e),{locationStyles:T}=ie(e),{positionClasses:_}=le(e),{roundedClasses:B}=se(e),c=ce(e,t),L=P(()=>e.link!==!1&&c.isLink.value),r=P(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return b(()=>{const N=L.value?"a":e.tag,R=!!(a.title||e.title!=null),F=!!(a.subtitle||e.subtitle!=null),O=R||F,E=!!(a.append||e.appendAvatar||e.appendIcon),w=!!(a.prepend||e.prependAvatar||e.prependIcon),G=!!(a.image||e.image),H=O||w||E,M=!!(a.text||e.text!=null);return ke(n(N,be({class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},v.value,l.value,o.value,s.value,x.value,D.value,_.value,B.value,y.value,e.class],style:[m.value,d.value,T.value,e.style],onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},c.linkProps),{default:()=>{var I;return[G&&n("div",{key:"image",class:"v-card__image"},[a.image?n(k,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(re,{key:"image-img",cover:!0,src:e.image},null)]),n(ue,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),H&&n(pe,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),M&&n(Ce,{key:"text"},{default:()=>{var C;return[((C=a.text)==null?void 0:C.call(a))??e.text]}}),(I=a.default)==null?void 0:I.call(a),a.actions&&n(Ve,null,{default:a.actions}),ve(r.value,"v-card")]}}),[[ge("ripple"),r.value&&e.ripple]])}),{}}});export{De as V,Ve as a};
