import{m as s,b as r,c,X as n}from"./VListItem-B_TSjQ1y.js";import{p as o,k as l,f as i}from"./index-CLKg64ON.js";const d=o({opacity:[Number,String],...s(),...r()},"VCardSubtitle"),y=l()({name:"VCardSubtitle",props:d(),setup(t,a){let{slots:e}=a;return c(()=>i(t.tag,{class:["v-card-subtitle",t.class],style:[{"--v-card-subtitle-opacity":t.opacity},t.style]},e)),{}}}),C=n("v-card-title"),m=o({opacity:[Number,String],...s(),...r()},"VCardText"),V=l()({name:"VCardText",props:m(),setup(t,a){let{slots:e}=a;return c(()=>i(t.tag,{class:["v-card-text",t.class],style:[{"--v-card-text-opacity":t.opacity},t.style]},e)),{}}});export{C as V,y as a,V as b};
