import{d as l,ak as u,x as p,l as c,c as a,h as m,f as i,g as d,w as v,e as g,m as f}from"./index-CLKg64ON.js";import{T as h}from"./Toolbar-BaIn3BvJ.js";import{V as y}from"./VList-BvG6-yh2.js";import"./VToolbar-DSn0RyUD.js";import"./VListItem-B_TSjQ1y.js";import"./VMenu-CLSWQG_U.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";const S=l({__name:"Settings",setup(b){const o=u(),r=p(()=>{var e,t,n;return(e=o.currentRoute.value.name)!=null&&e.toString().includes("player")?"players":(t=o.currentRoute.value.name)!=null&&t.toString().includes("core")?"core":(n=o.currentRoute.value.name)!=null&&n.toString().includes("frontend")?"frontend":"providers"});return(e,t)=>{const n=c("router-view");return a(),m("div",null,[i(h,{icon:"mdi-cog-outline",title:e.$t("settings.settings"),"show-loading":!0,"menu-items":[{label:"settings.providers",icon:"mdi-apps",action:()=>{e.$router.push({name:"providersettings"})},active:r.value=="providers"},{label:"settings.players",icon:"mdi-speaker-multiple",action:()=>{e.$router.push({name:"playersettings"})},active:r.value=="players"},{label:"settings.core",icon:"mdi-engine",action:()=>{e.$router.push({name:"coresettings"})},active:r.value=="core"},{label:"settings.frontend",icon:"mdi-palette-advanced",action:()=>{e.$router.push({name:"frontendsettings"})},active:r.value=="frontend"}]},null,8,["title","menu-items"]),i(y),t[0]||(t[0]=d("div",{style:{height:"15px"}},null,-1)),i(n,{app:""},{default:v(({Component:s})=>[(a(),g(f(s)))]),_:1})])}}});export{S as default};
