import{p as g,k as D,y as M,d as P,O as I,c as a,e as n,w as o,N as S,D as N,a3 as V,f as u,j as d,g as C,u as h,M as O,h as v,t as r,W as b,Z as X}from"./index-CLKg64ON.js";import{V as Y,M as _,v as $,e as L}from"./VCheckbox-CpTv3BhW.js";import{V as T}from"./VCard-BaRPabiE.js";import{e as z,g as F,c as H}from"./VMenu-CLSWQG_U.js";import{A,B as w,V as E,s as j}from"./VListItem-B_TSjQ1y.js";import{_ as R}from"./_plugin-vue_export-helper-DlAUqK2U.js";const W=g({disabled:Boolean,modelValue:{type:Boolean,default:null},...z()},"VHover"),Z=D()({name:"VHover",props:W(),emits:{"update:modelValue":l=>!0},setup(l,p){let{slots:t}=p;const s=M(l,"modelValue"),{runOpenDelay:m,runCloseDelay:f}=F(l,i=>!l.disabled&&(s.value=i));return()=>{var i;return(i=t.default)==null?void 0:i.call(t,{isHovering:s.value,props:{onMouseenter:m,onMouseleave:f}})}}}),q=["model-value"],G={key:0},J={key:1},K={key:2},Q=P({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1}},emits:["menu","click","play","select"],setup(l,{emit:p}){const t=l,s=p,m=function(e){if(t.showCheckboxes)return;const k="clientX"in e?e.clientX:e.touches[0].clientX,y="clientY"in e?e.clientY:e.touches[0].clientY;s("menu",t.item,k,y)},f=function(e){if(t.showCheckboxes){s("select",t.item,!t.isSelected);return}s("click",t.item,e.clientX,e.clientY)},i=function(e){t.showCheckboxes||s("play",t.item,e.clientX,e.clientY)};return(e,k)=>{const y=I("hold");return a(),n(Z,null,{default:o(({isHovering:c,props:B})=>[S((a(),n(T,N(B,{class:{"on-hover":c},elevation:c?3:0,onClick:f,onContextmenu:V(m,["right","prevent"])}),{default:o(()=>[e.showCheckboxes?(a(),n(H,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:o(()=>[u(Y,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):d("",!0),u(_,{item:e.item},null,8,["item"]),C("div",{class:X(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":c||e.$vuetify.display.mobile||e.permanentOverlay},[u(E,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:o(()=>[u(A,null,{default:o(()=>[e.item.media_type==h(O).FOLDER?(a(),v("span",G,[C("span",null,r(h($)(e.item,e.$t)),1)])):(a(),v("span",J,r(e.item.name),1)),"version"in e.item&&e.item.version?(a(),v("span",K," - "+r(e.item.version),1)):d("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(a(),n(w,{key:0,class:"line-clamp-1"},{default:o(()=>[b(r(h(L)(e.item.artists,1)),1)]),_:1})):"owner"in e.item&&e.item.owner?(a(),n(w,{key:1,class:"line-clamp-1"},{default:o(()=>[b(r(e.item.owner),1)]),_:1})):d("",!0)]),_:1})],10,q),c||e.$vuetify.display.mobile?(a(),n(j,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:V(i,["stop"])})):d("",!0)]),_:2},1040,["class","elevation"])),[[y,m]])]),_:1})}}}),oe=R(Q,[["__scopeId","data-v-fe06d440"]]);export{oe as P,Z as V};
